# Calculated Fields in Surveys
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/calculated-fields-in-surveys#introduction)
  * [Configuring Calculated Fields](https://help.sap.com/docs/leanix/ea/calculated-fields-in-surveys#configuring-calculated-fields)
  * [Processing Answers in Calculated Fields](https://help.sap.com/docs/leanix/ea/calculated-fields-in-surveys#processing-answers-in-calculated-fields)
  * [Writing Calculated Fields to Fact Sheets](https://help.sap.com/docs/leanix/ea/calculated-fields-in-surveys#writing-calculated-fields-to-fact-sheets)
  * [Examples](https://help.sap.com/docs/leanix/ea/calculated-fields-in-surveys#examples)
  * [Number Input Questions: Calculating the Sum of Answers](https://help.sap.com/docs/leanix/ea/calculated-fields-in-surveys#number-input-questions:-calculating-the-sum-of-answers)
  * [Single-Select Questions: Assigning Scores to Answers](https://help.sap.com/docs/leanix/ea/calculated-fields-in-surveys#single-select-questions:-assigning-scores-to-answers)
  * [Multiple-Select Questions: Assigning Scores to Answers](https://help.sap.com/docs/leanix/ea/calculated-fields-in-surveys#multiple-select-questions:-assigning-scores-to-answers)


View all
Learn how to configure calculated fields in surveys using JavaScript for advanced analysis and manipulation of data collected from survey responses.
